# Acrome-Joint-python-library

This library provides an interface to control Acrome Joint systems using Python. One of the most useful features of the library is its user-friendly graphical user interface (GUI).

## Using the GUI Tool

Launching the GUI tool that comes with the library is quite simple. All you need to do is open your command prompt (CMD) or terminal and run the following command:

```bash
joint_GUI
```

## Images from Joint GUI tool

![Acrome Joint GUI config tab](./images/config_tab.png)
![Acrome Joint GUI operation tab](./images/operation_tab.png)
